import Config from "./Config.js";
import Logger from "./utils/Logger.js";
import StarGazer from "./game/StarGazer.js";
import FakeGazeDataProvider from "./gaze/FakeGazeDataProvider.js";
import GazeDataProvider from "./gaze/GazeDataProvider.js";

var canvas = document.querySelector("canvas"),
  starScreen = document.querySelector("#startScreen");

function init() {
  if (Config.USE_LOGGER === true) {
    Logger.enable();
  }
  document.querySelector("#startButton").addEventListener("click",
    prepareGame);
}

function prepareGame() {
  let dataProvider = getDataProvider();
  StarGazer.init({
    canvas: canvas,
    fps: Config.TARGET_FPS,
    version: `Star Gazer, build ${Config.GAME_VERSION}`,
    showDebug: Config.SHOW_DEBUG_INFO,
    width: Config.SCREEN_WIDTH,
    height: Config.SCREEN_HEIGHT,
    gazeDataProvider: dataProvider,
  });
  canvas.requestFullscreen().then(startGame);
}

function startGame() {
	starScreen.classList.add("hidden");
	canvas.classList.remove("hidden");
}

function getDataProvider() {
  let provider;
  if (Config.USE_MOUSE_INPUT_AS_FAKE_GAZE_DATA === true) {
    provider = new FakeGazeDataProvider();
  } else {
    provider = new GazeDataProvider();
  }
  provider.start(Config.GAZE_SERVER_URL);
  return provider;
}

init();